@@ -5,7 +5,8 @@ from autotrader.comms import emailing
 from datetime import datetime, timezone
 from autotrader.autodata import AutoData
 from autotrader.brokers.trading import Order
-from autotrader.utilities import read_yaml, get_data_config, TradeAnalysis
+from concurrent.futures import ThreadPoolExecutor
+from autotrader.utilities import get_data_config, TradeAnalysis
 
 
 class AutoTraderBot:
@@ -79,6 +80,12 @@ class AutoTraderBot:
         self.instrument = instrument
         self._broker = broker
 
+        # # Define execution framework
+        if self._execution_method is None:
+            self._execution_method = self._submit_order
+        # # TODO - allow custom spec
+        # self._execution_method = self._submit_order
+
         # Check for muliple brokers and construct mapper
         if self._multiple_brokers:
             # Trading across multiple venues
@@ -307,32 +314,36 @@ class AutoTraderBot:
             self._qualify_orders(orders, current_bars, quote_bars)
 
             # Submit orders
-            for order in orders:
-                if self._scan_mode:
-                    # Bot is scanning
-                    scan_hit = {
-                        "size": order.size,
-                        "entry": current_bars[order.instrument].Close,
-                        "stop": order.stop_loss,
-                        "take": order.take_profit,
-                        "signal": order.direction,
-                    }
-                    self._scan_results[self.instrument] = scan_hit
+            with ThreadPoolExecutor(max_workers=8) as executor:
+                for order in orders:
+                    if self._scan_mode:
+                        # Bot is scanning
+                        scan_hit = {
+                            "size": order.size,
+                            "entry": current_bars[order.instrument].Close,
+                            "stop": order.stop_loss,
+                            "take": order.take_profit,
+                            "signal": order.direction,
+                        }
+                        self._scan_results[self.instrument] = scan_hit
 
-                else:
-                    # Bot is trading
-                    try:
-                        order_time = current_bars[order.instrument].name
-                    except:
-                        if self._feed == "none":
-                            order_time = datetime.now()
-                        else:
-                            order_time = current_bars[order.data_name].name
+                    else:
+                        # Bot is trading
+                        try:
+                            order_time = current_bars[order.instrument].name
+                        except:
+                            if self._feed == "none":
+                                order_time = datetime.now()
+                            else:
+                                order_time = current_bars[order.data_name].name
 
-                    # Submit order to relevant exchange
-                    self._brokers[order.exchange].place_order(
-                        order, order_time=order_time
-                    )
+                        # Submit order to relevant exchange
+                        executor.submit(
+                            self._execution_method,
+                            broker=self._brokers[order.exchange],
+                            order=order,
+                            order_time=order_time,
+                        )
 
             if self._papertrading:
                 # Update virtual broker again to trigger any orders
@@ -441,7 +452,9 @@ class AutoTraderBot:
                     + "insufficient data, or no new data. If you believe "
                     + "this is an error, try setting allow_dancing_bears to "
                     + "True, or set allow_duplicate_bars to True in "
-                    + "AutoTrader.configure()."
+                    + "AutoTrader.configure().\n"
+                    + f"Sufficient data: {sufficient_data}\n"
+                    + f"New data: {new_data}"
                 )
 
     def _refresh_data(self, timestamp: datetime = None, **kwargs):
@@ -1054,3 +1067,8 @@ class AutoTraderBot:
         """
         self.data = data
         self._strategy.data = data
+
+    @staticmethod
+    def _submit_order(broker, order, *args, **kwargs):
+        "The default order execution method."
+        broker.place_order(order, *args, **kwargs)
