@@ -99,6 +99,7 @@ class AutoTrader:
         self._maintain_broker_thread = False
 
         # Broker parameters
+        self._execution_method = None  # Execution method
         self._broker = None  # Broker instance(s)
         self._broker_name = ""  # Broker name(s)
         self._broker_utils = None  # Broker utilities
@@ -176,6 +177,7 @@ class AutoTrader:
         self,
         verbosity: int = 1,
         broker: str = None,
+        execution_method: Callable = None,
         feed: str = None,
         req_liveprice: bool = False,
         notify: int = 0,
@@ -203,6 +205,10 @@ class AutoTrader:
         broker : str, optional
             The broker(s) to connect to for trade execution. Multiple exchanges
             can be provided using comma separattion. The default is 'virtual'.
+        execution_method : Callable, optional
+            The execution model to call when submitting orders to the broker.
+            This method must accept the broker instance, the order object,
+            order_time and any *args, **kwargs.
         feed : str, optional
             The data feed to be used. This can be the same as the broker
             being used, or another data source. Options include 'yahoo',
@@ -270,6 +276,7 @@ class AutoTrader:
         self._feed = feed
         self._req_liveprice = req_liveprice
         self._broker_name = broker if broker is not None else self._broker_name
+        self._execution_method = execution_method
         self._notify = notify
         self._home_dir = home_dir if home_dir is not None else os.getcwd()
         self._allow_dancing_bears = allow_dancing_bears
@@ -530,7 +537,6 @@ class AutoTrader:
             sys.exit(0)
             # self._broker_name += broker_name + ', '
 
-        self._environment = "paper"
         self._papertrading = False if self._backtest_mode else papertrade
         self._broker_refresh_freq = refresh_freq
 
@@ -953,13 +959,13 @@ class AutoTrader:
                 self._notify = 0
 
             # Check that the backtest does not request future data
-            if self._data_end > datetime.now(tz=timezone.utc):
+            if self._data_end > datetime.now(tz=self._data_end.tzinfo):
                 print(
                     "Warning: you have requested backtest data into the "
                     + "future. The backtest end date will be adjsuted to "
                     + "the current time."
                 )
-                self._data_end = datetime.now(tz=timezone.utc)
+                self._data_end = datetime.now(tz=self._data_end.tzinfo)
 
             # Check if the broker has been configured
             if len(self._virtual_broker_config) != self._no_brokers:
@@ -2014,12 +2020,13 @@ class AutoTrader:
                         try:
                             for bot in self._bots_deployed:
                                 try:
+                                    # TODO - why UTC?
                                     bot._update(timestamp=datetime.now(timezone.utc))
 
                                 except:
                                     if int(self._verbosity) > 0:
                                         print(
-                                            "Error: failed to update bot running"
+                                            "Error: failed to update bot running "
                                             + f"{bot._strategy_name} ({bot.instrument})"
                                         )
                                         traceback.print_exc()
