@@ -81,13 +81,14 @@ class Broker:
                     symbol=order.instrument,
                     type=order.order_type,
                     side=side,
-                    amount=order.size,
+                    amount=abs(order.size),
                     price=order.order_limit_price,
                     params=order.ccxt_params,
                 )
             except Exception as e:
                 # An error occured, return the exception
                 placed_order = e
+                # print("Exception causing order: ", order)
 
         return placed_order
 
@@ -221,8 +222,16 @@ class Broker:
         """Returns a CCXT trade as a native AutoTrader Trade."""
         direction = 1 if trade["side"] == "buy" else -1
 
-        # parent_order_id = trade['info']['orderId']
-        parent_order_id = trade["info"]["orderID"]
+        order_id_keys = ["orderID", "orderId2"]
+        oid_assigned = False
+        for key in order_id_keys:
+            if key in trade["info"]:
+                parent_order_id = trade["info"][key]
+                oid_assigned = True
+                break
+
+        if not oid_assigned:
+            parent_order_id = None
 
         native_trade = Trade(
             instrument=trade["symbol"],
@@ -246,9 +255,9 @@ class Broker:
         """
         # Get symbol
         try:
-            symbol = position["info"]["symbol"]
-        except:
             symbol = position["symbol"]
+        except:
+            symbol = position["info"]["symbol"]
 
         direction = 1 if position["side"] == "long" else -1
 
