@@ -302,11 +302,22 @@ def get_data_config(feed: str, global_config: dict = None, **kwargs) -> dict:
     elif feed.lower() == "ccxt":
         # Try add authentication with global config
         if global_config is not None:
-            environment = kwargs["environment"] if "environment" in kwargs else "paper"
-            config = get_broker_config(
-                broker=f"{feed.lower()}:{exchange}", environment=environment
-            )
+            # Global config is available
+            try:
+                # Try get api keys
+                environment = (
+                    kwargs["environment"] if "environment" in kwargs else "paper"
+                )
+                config = get_broker_config(
+                    broker=f"{feed.lower()}:{exchange}",
+                    global_config=global_config,
+                    environment=environment,
+                )
+            except:
+                # Didn't work, just set exchange
+                config["exchange"] = exchange
         else:
+            # No global config available, just set exchange
             config["exchange"] = exchange
 
     return config
@@ -966,12 +977,20 @@ class TradeAnalysis:
                 # Position has not been closed yet
                 trade_results["all_trades"]["avg_trade_duration"] = None
 
-            min_trade_duration = np.nanmin(
-                self.isolated_position_history.trade_duration.values
-            )
-            max_trade_duration = np.nanmax(
-                self.isolated_position_history.trade_duration.values
-            )
+            # Trade durations
+            duration_list = [
+                i
+                for i in self.isolated_position_history.trade_duration.values
+                if i is not None
+            ]
+            if len(duration_list) > 0:
+                min_trade_duration = np.nanmin(duration_list)
+                max_trade_duration = np.nanmax(duration_list)
+            else:
+                min_trade_duration = None
+                max_trade_duration = None
+
+            # Fees
             total_fees = self.trade_history.fee.sum()
 
             trade_results["all_trades"]["avg_win"] = avg_win
